@@ -164,11 +164,9 @@ covmodel <- function(modelname, mev, nugget, variance, scale, parameter = NULL,
     {
 	if(modelname == "hyperbolic")
 	{
-	    print(parameter)
 	    a <- m$parameter.interval[ modelname == m$model ][[1]][[1]][1]
 	    b <- m$parameter.interval[ modelname == m$model ][[1]][[2]][1]
 	    c <- m$parameter.interval[ modelname == m$model ][[1]][[3]][1]
-	    print(c(a,b,c))
 	    if( parameter[2] < b )
 	    {
 		if( parameter[1] < a || parameter[3] <= c){stop("parameter a has to be >= 0 and c > 0 if b < 0 ") }
