@@ -12,17 +12,17 @@ f.polygons.preCKrige <- function(
 				pheight,
 				napp = 1
 			    )
-{   
+{
 #
 # no attributes -> only for ordinary kriging
 # add an empty data.frame to the Polygons
 # and build Class SpatialPolygonsDataFrame
-if( class( newdata ) == "SpatialPolygons" ) 
+if( class( newdata ) == "SpatialPolygons" )
 {
     data = as.data.frame( matrix( ncol = 0, nrow = 0 ) )
 }
 #
-if( class( newdata ) == "SpatialPolygonsDataFrame" ) 
+if( class( newdata ) == "SpatialPolygonsDataFrame" )
 {
     data = newdata@data
 }
@@ -41,21 +41,21 @@ if( missing( neighbours ) )
 stopifnot( is.list(neighbours) )
 #
 #
-pixgrid <- f.pixelgrid(
+pixgrid<- f.pixelgrid(
     			polygons = newdata.polygons,
 			neighbours = neighbours,
     			pixel.x.width = pwidth,
 			pixel.y.width = pheight
 		    )
 #
-## Kovarianzmatrix der Pixel		    
+## Kovarianzmatrix der Pixel
 pixcm <- f.pixelcovmat(
               		pixgrid = pixgrid,
               		model = model.me.free
 		    )
 
-#	    
-t.n.poly <- as.list( 1:length( newdata.polygons@polygons ) )	    
+#
+t.n.poly <- as.list( 1:length( newdata.polygons@polygons ) )
 for( i in 1:napp ){
 # pc.tmp = pixconfig.temporary
 pc.tmp <- f.pixconfig(
@@ -68,16 +68,16 @@ if( i == 1 )
 {
     pixconfig = pc.tmp
 }
-else 
+else
 {
 t2 <- proc.time()[3]
 pixconfig <- lapply( pixconfig,
     function( pc, pc.tmp )
     {
-	pc$pixcenter <- cbind( pc$pixcenter, 
+	pc$pixcenter <- cbind( pc$pixcenter,
 	    pc.tmp[[ pc$posindex[1] ]]$pixcenter )
 	pc$pix.in.poly <- cbind( pc$pix.in.poly, pc.tmp[[ pc$posindex[1] ]]$pix.in.poly )
-	pc$sa.polygons  <- c(pc$sa.polygons, 
+	pc$sa.polygons  <- c(pc$sa.polygons,
 	    pc.tmp[[ pc$posindex[1] ]]$sa.polygons)
 	return(pc)
     },
@@ -94,17 +94,17 @@ cm.list <- f.polygoncovmat(
 		model = model.me.free,
 		n = napp
 	    )
-	 
+
 #
 return( new( "preCKrigePolygons",
 	covmat = cm.list$mean.bb.cov.mat, # block block Covariance Matrix
 	se.covmat = cm.list$var.mean.bb.cov.mat, # standard error of block block Covariance
-	pixconfig = pixconfig, 
+	pixconfig = pixconfig,
 	pixcovmat = pixcm,
     	model = model,
-	data = data, 
+	data = data,
 	polygons = newdata@polygons
     )
 )
-rm( pixcm, newdata.polygons, pixconfig, cm.list)
-}
\ No newline at end of file
+rm( pixcm, pixgrid, newdata.polygons, pixconfig, cm.list)
+}
